Basics
******

Setup the project
=================
.. cmake-module:: ../../base.cmake

C++ Headers
===========
.. cmake-module:: ../../header.cmake

Version
===========
.. setmode:: user

.. cmake-module:: ../../version.cmake

Set a minimal C++ standard
==========================
.. cmake-module:: ../../cxx-standard.cmake

.. _minimal-working-example:

Minimal working example
=======================

.. literalinclude:: ../examples/minimal.cmake
  :language: cmake

Code documentation using Doxygen
================================
.. cmake-module:: ../../doxygen.cmake
